resource_name :intellij_sdk
default_action :add

property :workspace, String, required: true
property :sdk_name, String, name_property: true
property :path, String
property :type, Symbol, equal_to: [:JavaSDK, :RUBY_SDK], default: :JavaSDK
property :user, String
property :group, String

include IntelliJ::Helpers

action :add do
  begin
    args = @new_resource
    jdk_table_file = format(node['intellij']['workspace']['config']['sdk'], path: args.workspace)

    directory ::File.dirname(jdk_table_file) do
      recursive true
      user args.user
      group args.group
    end

    template jdk_table_file do
      source 'workspace/jdk.table.xml'
      user args.user
      group args.group
      cookbook 'intellij'
      action :create_if_missing
    end

    create_missing_component('ProjectJdkTable', jdk_table_file, nil, 'application')

    roots_config = format(node['intellij']['sdk']['roots'][args.type], path: args.path)

    xml_edit jdk_table_file do
      parent '/application/component[@name="ProjectJdkTable"]'
      target "/application/component[@name=\"ProjectJdkTable\"]/jdk[name/@value=\"#{args.sdk_name}\"]"
      fragment <<-EOH
        <jdk version="2">
            <name value="#{args.name}" />
            <type value="#{args.type}" />
            <homePath value="#{args.path}" />
            #{roots_config}
        </jdk>
      EOH
      action :append_if_missing
    end
  end
end

action :delete do
  begin
    args = @new_resource
    file = format(node['intellij']['workspace']['config']['sdk'], path: args.workspace)

    xml_edit file do
      target "/application/component[@name=\"ProjectJdkTable\"]/jdk[name/@value=\"#{args.sdk_name}\"]"
      action :remove
      only_if { ::File.exist?(file) }
    end
  end
end
