resource_name :intellij_workspace
default_action :create

property :intellij_path, String
property :path, String, name_property: true
property :default_project, String
property :color_scheme, Symbol, equal_to: [:IntelliJ, :Darcula]
property :user, String
property :group, String

include IntelliJ::Workspace

action :create do
  begin
    args = @new_resource

    directory args.path do
      recursive true
      user args.user
      group args.group
    end

    directory format(node['intellij']['workspace']['config_dir'], path: args.path) do
      recursive true
      user args.user
      group args.group
    end

    variables = {
      CONFIG_PATH: format(node['intellij']['workspace']['config_dir'], path: args.path),
    }

    template 'Create idea.properties for the new workspace' do
      source 'workspace/idea.properties.erb'
      path format(node['intellij']['workspace']['config']['properties'], path: args.path)
      variables variables
      cookbook 'intellij'
      user args.user
      group args.group
    end

    directory format(node['intellij']['workspace']['options_dir'], path: args.path) do
      recursive true
      user args.user
      group args.group
    end

    if args.default_project
      Chef::Log.info("Setting up the default project as #{args.default_project}")
      recent_projects_file = format(node['intellij']['workspace']['config']['recent-projects'], path: args.path)

      template recent_projects_file do
        source 'workspace/recentProjects.xml'
        cookbook 'intellij'
        user args.user
        group args.group
        action :create_if_missing
      end

      create_missing_component('RecentProjectsManager', recent_projects_file, nil, 'application')

      xml_edit recent_projects_file do
        edits generate_recent_projects_bulk(args.default_project)
        action :bulk
      end
    end

    if args.color_scheme
      color_file = format(node['intellij']['workspace']['config']['color-scheme'], path: args.path)
      laf_file = format(node['intellij']['workspace']['config']['laf'], path: args.path)

      template color_file do
        source 'workspace/colors.scheme.xml'
        cookbook 'intellij'
        user args.user
        group args.group
        action :create_if_missing
      end

      template laf_file do
        source 'workspace/laf.xml'
        cookbook 'intellij'
        user args.user
        group args.group
        action :create_if_missing
      end

      xml_edit color_file do
        parent '/application/component[@name="EditorColorsManagerImpl"]'
        target '/application/component[@name="EditorColorsManagerImpl"]/global_color_scheme'
        fragment "<global_color_scheme name=\"#{args.color_scheme}\" />"
        action :append_if_missing
      end

      xml_edit laf_file do
        parent '/application/component[@name="LafManager"]'
        target '/application/component[@name="LafManager"]/laf'
        fragment node['intellij']['workspace']['laf'][args.color_scheme]
        action :append_if_missing
      end
    end

    properties_path = format(node['intellij']['workspace']['config']['properties'], path: args.path)

    windows_shortcut format(node['intellij']['helpers']['shortcut_name'], path: args.path) do
      cwd format(node['intellij']['helpers']['shortcut_cwd'], path: args.path)
      target 'C:\Windows\System32\cmd.exe'
      arguments format(node['intellij']['helpers']['shortcut_arguments'], path: properties_path, ij_path: args.intellij_path)
      iconlocation format(node['intellij']['helpers']['icon_location'], path: args.intellij_path)
      only_if { Chef::Platform.windows? }
    end

    variables = {
      PATH: properties_path,
      INTELLIJ_PATH: args.intellij_path,
    }

    template "#{args.path}/idea.sh" do
      source 'workspace/start-script.sh.erb'
      user args.user
      group args.group
      mode '0755'
      variables variables
      not_if { Chef::Platform.windows? }
    end
  end
end

action :delete do
  begin
    args = @new_resource
    directory args.path do
      recursive true
      action :delete
    end
  end
end
