require 'spec_helper'

describe 'intellij_sdk' do
  let(:chef_conf) { ChefSpec::SoloRunner.new step_into: %w(intellij_sdk) }
  let(:workspace_path) { '/home/user/myworkspace' }
  let(:user) { 'myuser' }
  let(:group) { 'mygroup' }

  describe 'testing the resource' do
    let(:sdk_name) { 'JDK 10.0' }

    context 'creating the SDK' do
      let(:chef_run) { chef_conf.converge('test_intellij::sdk_create') }

      before do
        allow(File).to receive(:read).with(anything).and_call_original
        allow(File).to receive(:read).with("#{workspace_path}/config/options/jdk.table.xml").and_return '<application></application>'
      end

      it 'converges successfully' do
        expect { chef_run }.to_not raise_error
      end

      it 'configures the IntelliJ SDK' do
        expect(chef_run).to create_directory("#{workspace_path}/config/options").with(user: user, group: group)
        expect(chef_run).to create_template_if_missing("#{workspace_path}/config/options/jdk.table.xml").with(user: user, group: group)
        expect(chef_run).to append_if_missing_xml("#{workspace_path}/config/options/jdk.table.xml")
          .with(target: "/application/component[@name=\"ProjectJdkTable\"]/jdk[name/@value=\"#{sdk_name}\"]")
      end
    end

    context 'deleting the SDK' do
      let(:chef_run) { chef_conf.converge('test_intellij::sdk_delete') }

      before do
        allow(File).to receive(:exist?).with(anything).and_call_original
        allow(File).to receive(:exist?).with("#{workspace_path}/config/options/jdk.table.xml").and_return true
      end

      it 'converges successfully' do
        expect { chef_run }.to_not raise_error
      end

      it 'deletes the IntelliJ SDK' do
        expect(chef_run).to remove_xml("#{workspace_path}/config/options/jdk.table.xml")
          .with(target: "/application/component[@name=\"ProjectJdkTable\"]/jdk[name/@value=\"#{sdk_name}\"]")
      end
    end
  end
end
