require 'spec_helper'
require_relative '../../../../intellij/libraries/workspace'

describe 'intellij_workspace' do
  let(:chef_conf) { ChefSpec::SoloRunner.new step_into: %w(intellij_workspace) }
  let(:workspace_path) { '/home/user/myworkspace' }
  let(:user) { 'myuser' }
  let(:group) { 'mygroup' }

  describe 'testing the resource' do
    context 'creating the workspace' do
      let(:chef_run) { chef_conf.converge('test_intellij::workspace_create') }

      before do
        allow(File).to receive(:read).with(anything).and_call_original
        allow(File).to receive(:read).with("#{workspace_path}/config/options/recentProjects.xml").and_return '<application/>'
      end

      it 'converges successfully' do
        expect { chef_run }.to_not raise_error
      end

      it 'creates the workspace configuration' do
        expect(chef_run).to create_directory(workspace_path).with(user: user, group: group)
        expect(chef_run).to create_directory("#{workspace_path}/config").with(user: user, group: group)
        expect(chef_run).to create_directory("#{workspace_path}/config/options").with(user: user, group: group)
        expect(chef_run).to create_template("#{workspace_path}/config/idea.properties").with(user: user, group: group)
        expect(chef_run).to create_if_missing_template("#{workspace_path}/config/options/recentProjects.xml").with(user: user, group: group)
        expect(chef_run).to bulk_edit_xml("#{workspace_path}/config/options/recentProjects.xml")
        expect(chef_run).to create_if_missing_template("#{workspace_path}/config/options/colors.scheme.xml").with(user: user, group: group)
        expect(chef_run).to create_if_missing_template("#{workspace_path}/config/options/laf.xml").with(user: user, group: group)
        expect(chef_run).to append_if_missing_xml("#{workspace_path}/config/options/colors.scheme.xml").with(target: '/application/component[@name="EditorColorsManagerImpl"]/global_color_scheme')
        expect(chef_run).to append_if_missing_xml("#{workspace_path}/config/options/laf.xml").with(target: '/application/component[@name="LafManager"]/laf')
      end
    end

    context 'deleting the workspace' do
      let(:chef_run) { chef_conf.converge('test_intellij::workspace_delete') }

      it 'converges successfully' do
        expect { chef_run }.to_not raise_error
      end

      it 'deletes the workspace' do
        expect(chef_run).to delete_directory(workspace_path)
      end
    end
  end

  describe 'testing the artifact library' do
    before do
      class WorkspaceLibrary
        include IntelliJ::Plugins
      end
    end
  end
end
